Tets for validity of a covariance matrix based on four conditions:
symmetry, diagonal dominance, positive definiteness, and positive variance.
Usage
covmat.check(mat)
Value
A data.frame containing logical "TRUE" or "FALSE" for each condition.
Arguments
mat
A putative covariance matrix.
Details
A valid covariance matrix must be symmetric, diagonally dominant (largest values
in each row are on the diagonal), positive definite, and have positive variance.
covmat.check takes a matrix as input and tests for these four conditions.